summaryrefslogtreecommitdiffstats
path: root/tdeui/klistview.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:35:07 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:35:07 -0600
commit703fb0c89c2eee56a1e613e67a446db9d4287929 (patch)
treedd8c5ca66075cd89c2638a2b48cf78386a9870a7 /tdeui/klistview.h
parent818e7abec3d5d3809b6b77293558678371c16b71 (diff)
downloadtdelibs-703fb0c89c2eee56a1e613e67a446db9d4287929.tar.gz
tdelibs-703fb0c89c2eee56a1e613e67a446db9d4287929.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'tdeui/klistview.h')
-rw-r--r--tdeui/klistview.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/tdeui/klistview.h b/tdeui/klistview.h
index e60ae70b8..ee283aa5f 100644
--- a/tdeui/klistview.h
+++ b/tdeui/klistview.h
@@ -26,7 +26,7 @@
#include <tdelibs_export.h>
class TQDragObject;
-class KConfig;
+class TDEConfig;
class KLineEdit;
/**
* This Widget extends the functionality of TQListView to honor the system
@@ -350,20 +350,20 @@ public:
/**
* Saves the list view's layout (column widtsh, column order, sort column)
* to a KConfig group
*
* @param config the KConfig object to write to
* @param group the config group to use
*/
- void saveLayout(KConfig *config, const TQString &group) const;
+ void saveLayout(TDEConfig *config, const TQString &group) const;
/**
* Reads the list view's layout from a KConfig group as stored with
* saveLayout
*
* @param config the KConfig object to read from
* @param group the config group to use
*/
- void restoreLayout(KConfig *config, const TQString &group);
+ void restoreLayout(TDEConfig *config, const TQString &group);
/**
* Reimplemented to remember the current sort column and order.
* @param column is the column to be sorted, or -1 to sort in order of
@@ -350,20 +350,20 @@ public:
/**
* Saves the list view's layout (column widtsh, column order, sort column)
- * to a KConfig group
+ * to a TDEConfig group
*
@@ -350,20 +350,20 @@ public:
*
- * @param config the KConfig object to write to
+ * @param config the TDEConfig object to write to
* @param group the config group to use
*/
@@ -350,20 +350,20 @@ public:
/**
- * Reads the list view's layout from a KConfig group as stored with
+ * Reads the list view's layout from a TDEConfig group as stored with
* saveLayout
*
@@ -350,20 +350,20 @@ public:
* saveLayout
*
- * @param config the KConfig object to read from
+ * @param config the TDEConfig object to read from
* @param group the config group to use
*/